1. Testing (Python 3, Unicode, non-Posix platforms, etc).
2. Combining of multiple files...e.g. https://github.com/sontek/pyramid_webassets
4. Check forks: https://github.com/fuzeman/pyramid_assetcompiler/commits/master and https://github.com/ixmatus/pyramid_assetcompiler/commits/master
5. Add support for inline compiled output...?
6. Check into using tempate strings for mutators?? http://docs.python.org/library/string.html#template-strings
